unit BNWizEdt;

interface

{$IFDEF WIN32}
uses
  Classes, dsgnintf, menus;
{$ENDIF}

{$IFDEF LINUX}
uses
  Classes, DesignEditors, DesignIntf, menus;
{$ENDIF}

type

  { Component editors to add menu items to TBNWizard's popup menu at design-time
    We have to create similar editors for both the main Wizard component and the
    individual sheets, so that the popup menus are consistent }

  TBNWizEditor = class(TComponentEditor)
    function GetVerbCount : Integer; override;
    function GetVerb( Index : Integer ) : string; override;
  end;

  TBNWizardEditor = class(TBNWizEditor)
    procedure ExecuteVerb( Index : Integer ); override;
    procedure PrepareItem(Index: Integer; const AItem: TMenuItem); override;
  end;

  TBNWizSheetEditor = class(TBNWizEditor)
    procedure ExecuteVerb( Index : Integer ); override;
    procedure PrepareItem(Index: Integer; const AItem: TMenuItem); override;
  end;


procedure Register;

function GetNewComponentName( AOwner: TComponent; const BaseName: string ): string;

implementation

{$IFDEF WIN32}
uses
  BNWiz, ActnList, sysutils, windows, BNWizAbout;
{$ENDIF}

{$IFDEF LINUX}
uses
  BNWiz, QActnList, SysUtils, BNWizAbout;
{$ENDIF}

procedure Register;
begin
  RegisterComponentEditor(TBNWizard, TBNWizardEditor);
  RegisterComponentEditor(TBNWizSheet, TBNWizSheetEditor);
end;

{ GetNewComponentName from Raize Components }

function GetNewComponentName( AOwner: TComponent; const BaseName: string ): string;
var
  I: Integer;
begin
  Result := BaseName;
  I := 0;
  repeat
    Inc( I );
    Result := BaseName + IntToStr( I );
  until AOwner.FindComponent( Result ) = nil;
end; {= GetNewComponentName =}

{ TBNWizardEditor }

procedure TBNWizardEditor.ExecuteVerb(Index: Integer);
var
  CompOwner: TComponent;
  wsTemp: TBNWizSheet;
  frmAbout: TfrmAbout;
begin
//  inherited;
  case Index of
    0:                        // About box
    begin
      frmAbout := TfrmAbout.Create(nil);
      try
        frmAbout.ShowModal;
      finally
        frmAbout.Free;
      end;
    end;
    1:                        // New page
    begin
      {$IFDEF WIN32}
      CompOwner := Designer.GetRoot;
      {$ELSE}
        {$IFDEF LINUX}
        CompOwner := Designer.GetRoot;
        {$ELSE}
          // Assume Win16
          CompOwner := Designer.Form;
        {$ENDIF}
      {$ENDIF}
      if CompOwner <> nil then
      begin
        wsTemp := TBNWizSheet.Create( CompOwner );
        wsTemp.Name := GetNewComponentName( CompOwner, 'BNWizSheet' );
        wsTemp.Wizard := TBNWizard( Component );
        wsTemp.TabVisible := False;
        TBNWizard( Component ).ActivePage := wsTemp;

        Designer.Modified;
        Designer.SelectComponent(TBNWizard( Component ).ActivePage);
      end;
    end;
    2:                        // First page
    begin
      if Assigned((Component as TBNWizard).FirstSheet) then
      begin
        (Component as TBNWizard).ActivePage :=
                                  (Component as TBNWizard).FirstSheet;
      end
      else
      begin
        if (Component as TBNWizard).PageCount > 0 then
        begin
          (Component as TBNWizard).ActivePage :=
                                  (Component as TBNWizard).Pages[0];
        end;
      end;
        Designer.Modified;
        Designer.SelectComponent(TBNWizard( Component ).ActivePage);
    end;
    3:                        // Next page
    begin
      (Component as TBNWizard).Next;
        Designer.Modified;
        Designer.SelectComponent(TBNWizard( Component ).ActivePage);
    end;
    4:                        // Previous page
    begin
      (Component as TBNWizard).Back;
        Designer.Modified;
        Designer.SelectComponent(TBNWizard( Component ).ActivePage);
    end;
    5:                        // Delete page
    begin
      (Self.Component as TBNWizard).ActivePage.Free;
      Designer.Modified;
      if Assigned(TBNWizard( Component ).ActivePage) then
      begin
        Designer.SelectComponent(TBNWizard( Component ).ActivePage);
      end;
    end;
  end;
end;

procedure TBNWizardEditor.PrepareItem(Index: Integer; const AItem: TMenuItem);
var
  wTemp: TBNWizard;
begin
  if Component is TBNWizard then
  begin
    wTemp := Component as TBNWizard;
    case Index of
      // First Sheet
      1: AItem.Enabled := Assigned(wTemp.FirstSheet) and
                          Assigned(wTemp.ActivePage) and
                          (wTemp.FirstSheet <> wTemp.ActivePage);
      // Next Sheet
      2:
      begin
        AItem.Enabled := Assigned(wTemp.ActivePage) and
                         Assigned((wTemp.ActivePage as TBNWizSheet).NextSheet);
        AItem.ShortCut := ShortCut(VK_RIGHT, [ssCtrl, ssShift]);
      end;
      // Previous Sheet
      3:
      begin
        AItem.Enabled := Assigned(wTemp.ActivePage) and
                       (wTemp.WizFindNextPage((wTemp.ActivePage as TBNWizSheet),
                                                False) <>
                        wTemp.ActivePage);
        AItem.ShortCut := ShortCut(VK_LEFT, [ssCtrl, ssShift]);
      end;
      // Delete Sheet
      4: AItem.Enabled := Assigned(wTemp.ActivePage);
    end;
  end;
end;

{ TBNWizSheetEditor }

procedure TBNWizSheetEditor.ExecuteVerb(Index: Integer);
var
  CompOwner: TComponent;
  wsTemp: TBNWizSheet;
  frmAbout: TfrmAbout;
begin
//  inherited;
  case Index of
    0:                        // About box
    begin
      frmAbout := TfrmAbout.Create(nil);
      try
        frmAbout.ShowModal;
      finally
        frmAbout.Free;
      end;
    end;
    1:                        // New page
    begin
      {$IFDEF WIN32}
      CompOwner := Designer.GetRoot;
      {$ELSE}
        {$IFDEF LINUX}
        CompOwner := Designer.GetRoot;
        {$ELSE}
          // Assume Win16
          CompOwner := Designer.Form;
        {$ENDIF}
      {$ENDIF}
      if CompOwner <> nil then
      begin
        wsTemp := TBNWizSheet.Create( CompOwner );
        wsTemp.Name := GetNewComponentName( CompOwner, 'BNWizSheet' );
        wsTemp.Wizard := TBNWizSheet( Component ).Wizard;
        wsTemp.TabVisible := False;
        TBNWizSheet( Component ).Wizard.ActivePage := wsTemp;

        Designer.Modified;
        Designer.SelectComponent(TBNWizSheet( Component ).Wizard.ActivePage);
      end;
    end;
    2:                        // First page
    begin
      if Assigned((Component as TBNWizSheet).Wizard.FirstSheet) then
      begin
        (Component as TBNWizSheet).Wizard.ActivePage :=
                                  (Component as TBNWizSheet).Wizard.FirstSheet;
      end
      else
      begin
        if (Component as TBNWizSheet).Wizard.PageCount > 0 then
        begin
          (Component as TBNWizSheet).Wizard.ActivePage :=
                                  (Component as TBNWizSheet).Wizard.Pages[0];
        end;
      end;
        Designer.Modified;
        Designer.SelectComponent(TBNWizSheet( Component ).Wizard.ActivePage);
    end;
    3:                        // Next page
    begin
      (Component as TBNWizSheet).Wizard.Next;
        Designer.Modified;
        Designer.SelectComponent(TBNWizSheet( Component ).Wizard.ActivePage);
    end;
    4:                        // Previous page
    begin
      (Component as TBNWizSheet).Wizard.Back;
        Designer.Modified;
        Designer.SelectComponent(TBNWizSheet( Component ).Wizard.ActivePage);
    end;
    5:                        // Delete page
    begin
      (Self.Component as TBNWizSheet).Wizard.ActivePage.Free;
      Designer.Modified;
      if Assigned(TBNWizSheet( Component ).Wizard.ActivePage) then
      begin
        Designer.SelectComponent(TBNWizSheet( Component ).Wizard.ActivePage);
      end;
    end;
  end;
end;

procedure TBNWizSheetEditor.PrepareItem(Index: Integer; const AItem: TMenuItem);
var
  wsTemp: TBNWizSheet;
begin
  if Component is TBNWizSheet then
  begin
    wsTemp := Component as TBNWizSheet;
    case Index of
      // First Sheet
      1: AItem.Enabled := Assigned(wsTemp.Wizard.FirstSheet) and
                          (wsTemp.Wizard.FirstSheet <> wsTemp);
      // Next Sheet
      2:
      begin
        AItem.Enabled := Assigned(wsTemp.NextSheet);
        AItem.ShortCut := ShortCut(VK_RIGHT, [ssCtrl, ssShift]);
      end;
      // Previous Sheet
      3:
      begin
        AItem.Enabled := wsTemp.Wizard.WizFindNextPage(wsTemp, False) <> wsTemp;
        AItem.ShortCut := ShortCut(VK_LEFT, [ssCtrl, ssShift]);
      end;
    end;
  end;
end;

{ TBNWizEditor }

function TBNWizEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := 'About...';
    1: Result := 'Ne&w Sheet';
    2: Result := 'F&irst Sheet';
    3: Result := 'Ne&xt Sheet';
    4: Result := '&Previous Sheet';
    5: Result := '&Delete Sheet';
  end;
end;

function TBNWizEditor.GetVerbCount: Integer;
begin
  Result := 6;
end;

end.
